<p align="center">
  <a href="" rel="noopener">
 <img width=200px height=200px src="https://i.imgur.com/nkMr2fl.png" alt="Project logo"></a>
</p>

<h1 align="center">Spyctl</h1>

Spyctl, is a command-line utility for viewing and managing Spyderbat Resources. It provides basic
mechanisms for retrieving and uploading data via the [Spyderbat API](https://api.spyderbat.com/openapi.pdf).

Spyctl is the answer for those wanting a command-line solution to interact with Spyderbat.

---

<p align="center"> 
    <br> 
</p>

## Getting Started <a name = "getting_started"></a>

Follow the [Installation Guide](https://docs.spyderbat.com/installation/spyctl)

Or if you already have Spyctl installed explore the [Tutorials](https://docs.spyderbat.com/tutorials) section of the Spyderbat Docs

## Support <a name = "support"></a>

If you need support, you can reach out to us at dev@spyderbat.com or on our [community Slack workspace](https://join.slack.com/t/spyderbatcommunity/shared_invite/zt-1ncqumr1c-WVVRwJTNfTQSW2Y8_maGOw)


## ✍️ Authors <a name = "authors"></a>

- [@brent-spyder](https://github.com/brent-spyder) - Developer
- [@spyder-kyle](https://github.com/spyder-kyle) - Developer
